'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _react = require('react');

var _react2 = _interopRequireDefault(_react);

var _recompose = require('recompose');

var _ramda = require('ramda');

var _ramda2 = _interopRequireDefault(_ramda);

var _translate = require('./utils/translate');

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var groupChildrenPropsByX = _ramda2.default.pipe(_react.Children.toArray, _ramda2.default.map(_ramda2.default.pathOr([], ['props', 'data'])), _ramda2.default.flatten, _ramda2.default.groupBy(_ramda2.default.prop('x')));

var createTransformY = function createTransformY(groupedProps, yScale, index) {
  return function (datum) {
    var currentGroup = groupedProps[_ramda2.default.prop('x', datum)];

    var sumOfYOffset = _ramda2.default.compose(yScale, _ramda2.default.sum, _ramda2.default.map(_ramda2.default.prop('y')), _ramda2.default.take(index))(currentGroup);

    return _ramda2.default.assocPath(['props', 'transform'], (0, _translate.translateY)(sumOfYOffset - yScale(0)), datum);
  };
};

var enhance = (0, _recompose.setPropTypes)({
  yScale: _react.PropTypes.func,
  children: _react.PropTypes.arrayOf(_react.PropTypes.element)
});

var Stack = function Stack(_ref) {
  var children = _ref.children,
      yScale = _ref.yScale;

  // TODO: warn if children is not a array with at least 2 items

  var groupedProps = groupChildrenPropsByX(children);

  return _react2.default.createElement(
    'g',
    null,
    _react.Children.map(children, function (child, index) {
      if (index === 0) return child;

      var transformY = createTransformY(groupedProps, yScale, index);

      return (0, _react.cloneElement)(child, {
        data: child.props.data.map(transformY)
      });
    })
  );
};

exports.default = enhance(Stack);